toHeading method
Formats the string as a heading with proper capitalisation and spacing.
Currently not implemented.
Implementation
String toHeading() {
throw UnimplementedError('toHeading() not yet implemented');
}
Formats the string as a heading with proper capitalisation and spacing.
Currently not implemented.
String toHeading() {
throw UnimplementedError('toHeading() not yet implemented');
}